# libmonty - logging

Python library - logging-related

## License

[Mozilla Public License 2.0](https://www.mozilla.org/en-US/MPL/2.0/)

```
This Source Code Form is subject to the terms of the Mozilla Public
License, v. 2.0. If a copy of the MPL was not distributed with this
file, You can obtain one at http://mozilla.org/MPL/2.0/.
```

## Acknowledgements

- Python section in global .gitignore taken from [github/gitignore](https://github.com/github/gitignore) under the [CC0-1.0 License](https://choosealicense.com/licenses/cc0-1.0/).
